@@ -2,7 +2,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -454,7 +454,7 @@ read_file(const char *file_name, cf_t * cf, int is_system_startup)
     int flask_enabled = is_selinux_enabled();
     int retval;
     struct av_decision avd;
-    const char *user_name;
+    char *user_name = NULL;
 #endif
 
     /* open file */
@@ -464,7 +464,7 @@ read_file(const char *file_name, cf_t * cf, int is_system_startup)
     }
 
     /* check if this file is owned by root : otherwise, all runas fields
-     * of this field should be set to the owner */
+     * of this file should be set to the owner */
     rc = fstat(fileno(ff), &file_stat);
     if (rc != 0) {
         error_e("Could not stat %s", file_name);
@@ -511,30 +511,47 @@ read_file(const char *file_name, cf_t * cf, int is_system_startup)
 #ifdef WITH_SELINUX
     /*
      * Since fcrontab files are not directly executed,
-     * fcrond must ensure that the fcrontab file has
+     * fcron daemon must ensure that the fcrontab file has
      * a context that is appropriate for the context of
      * the user fcron job.  It performs an entrypoint
      * permission check for this purpose.
      */
-#ifdef SYSFCRONTAB
-    if (!strcmp(cf->cf_user, SYSFCRONTAB))
-        user_name = "system_u";
-    else
-#endif                          /* def SYSFCRONTAB */
-        user_name = cf->cf_user;
     if (flask_enabled) {
+        char *sename = NULL;
+        char *selevl = NULL;
+
+        /* first, get the SELinux user for that Linux user */
+#ifdef SYSFCRONTAB
+        if (!strcmp(cf->cf_user, SYSFCRONTAB))
+            /* system_u is the default SELinux user for running system services */
+            user_name = "system_u";
+        else
+#endif                          /* def SYSFCRONTAB */
+        {
+            if (getseuserbyname(cf->cf_user, &sename, &selevl) < 0) {
+                error_e("Cannot find SELinux user for user \"%s\"\n",
+                        cf->cf_user);
+                goto err;
+            }
+            user_name = sename;
+        }
+
         if (get_default_context(user_name, NULL, &cf->cf_user_context))
-            error_e("NO CONTEXT for user \"%s\"", cf->cf_user_context);
+            error_e("NO CONTEXT for Linux user '%s' (SELinux user '%s')",
+                    cf->cf_user, user_name);
         retval =
             security_compute_av(cf->cf_user_context, cf->cf_file_context,
                                 SECCLASS_FILE, FILE__ENTRYPOINT, &avd);
 
         if (retval || ((FILE__ENTRYPOINT & avd.allowed) != FILE__ENTRYPOINT)) {
-            syslog(LOG_ERR, "ENTRYPOINT FAILED for user \"%s\" "
+            syslog(LOG_ERR, "ENTRYPOINT FAILED for Linux user '%s' "
                    "(CONTEXT %s) for file CONTEXT %s", cf->cf_user,
                    cf->cf_user_context, cf->cf_file_context);
             goto err;
         }
+
+        Free_safe(sename);
+        Free_safe(selevl);
     }
 #endif
 
@@ -932,34 +949,35 @@ add_line_to_file(cl_t * cl, cf_t * cf, uid_t runas, char *runas_str,
                                            || is_runonce(cl->cl_option)))) {
             /* cl_first is always saved to disk for a volatile line */
             if (cl->cl_first == LONG_MAX) {
-                cl->cl_nextexe = LONG_MAX;
+                cl->cl_nextexe = TIME_T_MAX;
             }
             else {
                 cl->cl_nextexe = now + cl->cl_first;
-                if (cl->cl_nextexe < now) {
+                if (cl->cl_nextexe < now || cl->cl_nextexe > TIME_T_MAX) {
                     /* there was an integer overflow! */
                     error
                         ("Error while setting next exe time for job %s: cl_nextexe"
-                         " overflowed. now=%lu, cl_timefreq=%lu, cl_nextexe=%lu.",
+                         " overflowed (case1). now=%lu, cl_timefreq=%lu, cl_nextexe=%lu.",
                          cl->cl_shell, now, cl->cl_timefreq, cl->cl_nextexe);
                     error
-                        ("Setting cl_nextexe to LONG_MAX to prevent an infinite loop.");
-                    cl->cl_nextexe = LONG_MAX;
+                        ("Setting cl_nextexe to TIME_T_MAX to prevent an infinite loop.");
+                    cl->cl_nextexe = TIME_T_MAX;
                 }
             }
         }
         else {
             if (cl->cl_nextexe != LONG_MAX) {
                 cl->cl_nextexe += slept;
-                if (cl->cl_nextexe < now) {
+                if (cl->cl_nextexe < now || cl->cl_nextexe > TIME_T_MAX) {
                     /* there was an integer overflow! */
                     error
                         ("Error while setting next exe time for job %s: cl_nextexe"
-                         " overflowed. now=%lu, cl_timefreq=%lu, cl_nextexe=%lu.",
+                         " overflowed (case2). now=%lu, cl_timefreq=%lu, cl_nextexe=%lu.",
                          cl->cl_shell, now, cl->cl_timefreq, cl->cl_nextexe);
                     error
-                        ("Setting cl_nextexe to LONG_MAX to prevent an infinite loop.");
-                    cl->cl_nextexe = LONG_MAX;
+                        ("Setting cl_nextexe to TIME_T_MAX=%ld to prevent an infinite loop.",
+                         TIME_T_MAX);
+                    cl->cl_nextexe = TIME_T_MAX;
                 }
             }
         }
