@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -374,14 +374,15 @@ parseopt(int argc, char *argv[])
 
         case 's':
             if ((save_time = strtol(optarg, NULL, 10)) < 60
-                || save_time >= LONG_MAX)
-                die("Save time can only be set between 60 and %d.", LONG_MAX);
+                || save_time >= TIME_T_MAX)
+                die("Save time can only be set between 60 and %d.", TIME_T_MAX);
             break;
 
         case 'l':
             if ((first_sleep = strtol(optarg, NULL, 10)) < 0
-                || first_sleep >= LONG_MAX)
-                die("First sleep can only be set between 0 and %d.", LONG_MAX);
+                || first_sleep >= TIME_T_MAX)
+                die("First sleep can only be set between 0 and %d.",
+                    TIME_T_MAX);
             break;
 
         case 'm':
