@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2013 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2014 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -169,8 +169,10 @@ sig_daemon(void)
 
         sleep(sl);
 
+        /* also closes the underlying file descriptor fd: */
         xfclose_check(&fp, sigfile);
-        xclose_check(&fd, sigfile);
+        /* also reset fd, now closed by xfclose_check(), to make it clear it is closed */
+        fd = -1;
 
         if (remove(sigfile) < 0)
             error_e("Could not remove %s");
